PyXMake Developer Guide: PyXMake.VTL.doxygen Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Functions | Variables
PyXMake.VTL.doxygen Namespace Reference

## Functions
def | main (BuildID, title=["MCODAC", MCODAC, Developer, Guide, files=VTL.GetSourceCode(0), ftype="Fortran", source=os.path.join(__mcd_core_path,"src"), output=os.path.join(os.path.dirname(__mcd_core_path),"VTL","doc","mcd_core"), scratch=VTL.Scratch, verbosity=0, kwargs)

## Variables
| parser = argparse.ArgumentParser(description="Build shared Fortran libraries for Python remotely on the institute cluster.")
| args
| make_opt = args.make[0]
string | BuildID = "pyx_core"
| output
| source

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Create html source code documentations for PyXMake, PyCODAC,
                 MCODAC & BoxBeam with Doxygen.
    Created on 22.03.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake, PyCODAC

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

def PyXMake.VTL.doxygen.main | ( |  | BuildID,
|  |  | title = `["MCODAC"`,
|  |  | MCODAC,
|  |  | Developer,
|  |  | Guide,
|  |  | files = `VTL.GetSourceCode(0)`,
|  |  | ftype = `"Fortran"`,
|  |  | source = `os.path.join(__mcd_core_path,"src")`,
|  |  | output = `os.path.join(os.path.dirname(__mcd_core_path),"VTL","doc","mcd_core")`,
|  |  | scratch = `VTL.Scratch`,
|  |  | verbosity = `0`,
|  |  | kwargs
| ) |  |

    Main function to execute the script.

Definition at line 63 of file doxygen.py.